==> artemis_ui_kit-0.0.2.tar.gz: lib/src/ArtemisTimePickerDialog.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'Consts.dart';

class ArtemisTimePickerDialog extends StatefulWidget {
  final Duration? currentTime;

  const ArtemisTimePickerDialog({Key? key, this.currentTime}) : super(key: key);
  @override
  _ArtemisTimePickerDialogState createState() => _ArtemisTimePickerDialogState();
}

class _ArtemisTimePickerDialogState extends State<ArtemisTimePickerDialog> {
  late Duration tmpDuration;
  @override
  void initState() {
      tmpDuration = widget.currentTime??Duration(hours: 0,minutes: 0);
    super.initState();
  }
  @override
  Widget build(BuildContext context) {
    return Dialog(child: Container(
      decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.only(
            topLeft: Radius.circular(25),
            topRight: Radius.circular(25),
          )),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Padding(
            padding: const EdgeInsets.only(left: 36, right: 12, top: 36, bottom: 24),
            child: Row(
              children: [
                Text(
                  "Select Time",
                  style: TextStyle(fontSize: 22,fontWeight: FontWeight.bold),
                ),
                Spacer(),
                IconButton(
                    onPressed: () => Navigator.pop(context),
                    icon: Icon(
                      Icons.close,
                      color: ArtemisColors.brownGrey,
                    )),
              ],
            ),
          ),
          CupertinoTimerPicker(
            initialTimerDuration: tmpDuration,
            mode: CupertinoTimerPickerMode.hm,
            onTimerDurationChanged: (Duration value) {
              setState(() {
                tmpDuration =value;
              });
            },
          ),
          Padding(
            padding: const EdgeInsets.only(bottom: 12.0, right: 36, top: 0),
            child: Column(
              children: [
                Row(
                  children: [

                    Spacer(),
                    TextButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      child: Text("Cancel"),
                      style: TextButton.styleFrom(primary: ArtemisColors.brownGrey),
                    ),
                    SizedBox(
                        width: 24
                    ),
                    OutlinedButton(
                      onPressed:() {
                        Navigator.pop(context,tmpDuration);
                      },
                      child: Text("Apply"),
                      style: OutlinedButton.styleFrom(
                          primary: ArtemisColors.darkMint,
                          side: BorderSide(
                              color:  ArtemisColors.darkMint,
                              width: 2)),
                    )
                  ],
                ),
              ],
            ),
          ),
        ],
      ),
    ));
  }
}

==> artemis_ui_kit-0.0.12.tar.gz: lib/src/ArtemisTimePickerDialog.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'Consts.dart';

class ArtemisTimePickerDialog extends StatefulWidget {
  final Duration? currentTime;

  const ArtemisTimePickerDialog({Key? key, this.currentTime}) : super(key: key);
  @override
  _ArtemisTimePickerDialogState createState() =>
      _ArtemisTimePickerDialogState();
}

class _ArtemisTimePickerDialogState extends State<ArtemisTimePickerDialog> {
  late Duration tmpDuration;
  @override
  void initState() {
    tmpDuration = widget.currentTime ?? Duration(hours: 0, minutes: 0);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Dialog(
        child: Container(
      decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.only(
            topLeft: Radius.circular(25),
            topRight: Radius.circular(25),
          )),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Padding(
            padding:
                const EdgeInsets.only(left: 36, right: 12, top: 36, bottom: 24),
            child: Row(
              children: [
                Text(
                  "Select Time",
                  style: TextStyle(fontSize: 22, fontWeight: FontWeight.bold),
                ),
                Spacer(),
                IconButton(
                    onPressed: () => Navigator.pop(context),
                    icon: Icon(
                      Icons.close,
                      color: ArtemisColors.brownGrey,
                    )),
              ],
            ),
          ),
          CupertinoTimerPicker(
            initialTimerDuration: tmpDuration,
            mode: CupertinoTimerPickerMode.hm,
            onTimerDurationChanged: (Duration value) {
              setState(() {
                tmpDuration = value;
              });
            },
          ),
          Padding(
            padding: const EdgeInsets.only(bottom: 12.0, right: 36, top: 0),
            child: Column(
              children: [
                Row(
                  children: [
                    Spacer(),
                    TextButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      child: Text("Cancel"),
                      style: TextButton.styleFrom(
                          primary: ArtemisColors.brownGrey),
                    ),
                    SizedBox(width: 24),
                    OutlinedButton(
                      onPressed: () {
                        Navigator.pop(context, tmpDuration);
                      },
                      child: Text("Apply"),
                      style: OutlinedButton.styleFrom(
                          primary: ArtemisColors.darkMint,
                          side: BorderSide(
                              color: ArtemisColors.darkMint, width: 2)),
                    )
                  ],
                ),
              ],
            ),
          ),
        ],
      ),
    ));
  }
}
